@@ -44,6 +44,7 @@
 #include <libgimpwidgets/gimpcolorprofilestore.h>
 #include <libgimpwidgets/gimpcolorprofileview.h>
 #include <libgimpwidgets/gimpcolorscale.h>
+#include <libgimpwidgets/gimpcolorscaleentry.h>
 #include <libgimpwidgets/gimpcolorscales.h>
 #include <libgimpwidgets/gimpcolorselector.h>
 #include <libgimpwidgets/gimpcolorselect.h>
@@ -59,14 +60,19 @@
 #include <libgimpwidgets/gimphintbox.h>
 #include <libgimpwidgets/gimpicons.h>
 #include <libgimpwidgets/gimpintcombobox.h>
+#include <libgimpwidgets/gimpintradioframe.h>
 #include <libgimpwidgets/gimpintstore.h>
+#include <libgimpwidgets/gimplabelcolor.h>
+#include <libgimpwidgets/gimplabeled.h>
+#include <libgimpwidgets/gimplabelentry.h>
+#include <libgimpwidgets/gimplabelintwidget.h>
+#include <libgimpwidgets/gimplabelspin.h>
 #include <libgimpwidgets/gimpmemsizeentry.h>
 #include <libgimpwidgets/gimpnumberpairentry.h>
 #include <libgimpwidgets/gimpoffsetarea.h>
 #include <libgimpwidgets/gimppageselector.h>
 #include <libgimpwidgets/gimppatheditor.h>
 #include <libgimpwidgets/gimppickbutton.h>
-#include <libgimpwidgets/gimppixmap.h>
 #include <libgimpwidgets/gimppreview.h>
 #include <libgimpwidgets/gimppreviewarea.h>
 #include <libgimpwidgets/gimppropwidgets.h>
@@ -76,17 +82,14 @@
 #include <libgimpwidgets/gimpscrolledpreview.h>
 #include <libgimpwidgets/gimpsizeentry.h>
 #include <libgimpwidgets/gimpspinbutton.h>
+#include <libgimpwidgets/gimpspinscale.h>
 #include <libgimpwidgets/gimpstringcombobox.h>
 #include <libgimpwidgets/gimpunitcombobox.h>
-#include <libgimpwidgets/gimpunitmenu.h>
 #include <libgimpwidgets/gimpunitstore.h>
 #include <libgimpwidgets/gimpwidgets-error.h>
 #include <libgimpwidgets/gimpwidgetsutils.h>
 #include <libgimpwidgets/gimpzoommodel.h>
 
-#include <libgimpwidgets/gimp3migration.h>
-#include <libgimpwidgets/gimpoldwidgets.h>
-
 #undef __GIMP_WIDGETS_H_INSIDE__
 
 G_BEGIN_DECLS
@@ -98,71 +101,26 @@ G_BEGIN_DECLS
  *  Widget Constructors
  */
 
+/* specify radio buttons as va_list:
+ *  const gchar  *label,
+ *  gint          item_data,
+ *  GtkWidget   **widget_ptr,
+ */
 GtkWidget * gimp_int_radio_group_new (gboolean          in_frame,
                                       const gchar      *frame_title,
                                       GCallback         radio_button_callback,
                                       gpointer          radio_button_callback_data,
+                                      GDestroyNotify    radio_button_callback_destroy,
                                       gint              initial, /* item_data */
-
-                                      /* specify radio buttons as va_list:
-                                       *  const gchar  *label,
-                                       *  gint          item_data,
-                                       *  GtkWidget   **widget_ptr,
-                                       */
-
                                       ...) G_GNUC_NULL_TERMINATED;
 
 void        gimp_int_radio_group_set_active (GtkRadioButton *radio_button,
                                              gint            item_data);
 
 
-GtkWidget * gimp_radio_group_new   (gboolean            in_frame,
-                                    const gchar        *frame_title,
-
-                                    /* specify radio buttons as va_list:
-                                     *  const gchar    *label,
-                                     *  GCallback       callback,
-                                     *  gpointer        callback_data,
-                                     *  gpointer        item_data,
-                                     *  GtkWidget     **widget_ptr,
-                                     *  gboolean        active,
-                                     */
-
-                                    ...) G_GNUC_NULL_TERMINATED;
-GtkWidget * gimp_radio_group_new2  (gboolean            in_frame,
-                                    const gchar        *frame_title,
-                                    GCallback           radio_button_callback,
-                                    gpointer            radio_button_callback_data,
-                                    gpointer            initial, /* item_data */
-
-                                    /* specify radio buttons as va_list:
-                                     *  const gchar    *label,
-                                     *  gpointer        item_data,
-                                     *  GtkWidget     **widget_ptr,
-                                     */
-
-                                    ...) G_GNUC_NULL_TERMINATED;
-
-void   gimp_radio_group_set_active (GtkRadioButton     *radio_button,
-                                    gpointer            item_data);
-
-
-GIMP_DEPRECATED_FOR(gtk_spin_button_new)
-GtkWidget * gimp_spin_button_new   (/* return value: */
-                                    GtkObject         **adjustment,
-
-                                    gdouble             value,
-                                    gdouble             lower,
-                                    gdouble             upper,
-                                    gdouble             step_increment,
-                                    gdouble             page_increment,
-                                    gdouble             page_size,
-                                    gdouble             climb_rate,
-                                    guint               digits);
-
 /**
  * GIMP_RANDOM_SEED_SPINBUTTON:
- * @hbox: The #GtkHBox returned by gimp_random_seed_new().
+ * @hbox: The #GtkBox returned by gimp_random_seed_new().
  *
  * Returns: the random_seed's #GtkSpinButton.
  **/
@@ -171,7 +129,7 @@ GtkWidget * gimp_spin_button_new   (/* return value: */
 
 /**
  * GIMP_RANDOM_SEED_SPINBUTTON_ADJ:
- * @hbox: The #GtkHBox returned by gimp_random_seed_new().
+ * @hbox: The #GtkBox returned by gimp_random_seed_new().
  *
  * Returns: the #GtkAdjustment of the random_seed's #GtkSpinButton.
  **/
@@ -181,7 +139,7 @@ GtkWidget * gimp_spin_button_new   (/* return value: */
 
 /**
  * GIMP_RANDOM_SEED_TOGGLE:
- * @hbox: The #GtkHBox returned by gimp_random_seed_new().
+ * @hbox: The #GtkBox returned by gimp_random_seed_new().
  *
  * Returns: the random_seed's #GtkToggleButton.
  **/
